@@ -1,4 +1,4 @@
-""" CodeStar CLI """
+""" CodeStar CLI: CodeStar is an advanced coding assistant powered by StarCoder 2 """
 
 from rich.console import Console
 from rich.markdown import Markdown
@@ -14,7 +14,9 @@ SYSTEM_MESSAGE = {
     " a state-of-the-art Large Language Model for Code (Code LLM) trained on over 600 "
     "programming languages from a diverse set of permissively licensed data, including "
     "GitHub code, Arxiv, and Wikipedia. CodeStar is specifically optimized for enhanced "
-    "performance in coding tasks.",
+    "performance in coding tasks. You also a senior software engineer with a passion for "
+    "technology and a strong background in programming, senior software architect and "
+    "senior site reliability engineer.",
 }
 
 
@@ -34,6 +36,6 @@ def print_highlighted(code: str) -> None:
         Panel(
             md,
             title_align="left",
-            title="[bold green]CodePilot[/bold green]",
+            title="[bold green]CodeStar[/bold green]",
         )
     )
